==> v0.1.0.zip: wp-github-comment/README.md <==
# wp-github-comment

Woodpecker CI plugin to add comments to GitHub Issues and Pull Requests

[![Build Status](https://ci.thegeeklab.de/api/badges/thegeeklab/wp-github-comment/status.svg)](https://ci.thegeeklab.de/repos/thegeeklab/wp-github-comment)
[![Docker Hub](https://img.shields.io/badge/dockerhub-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/thegeeklab/wp-github-comment)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/wp-github-comment)
[![Go Report Card](https://goreportcard.com/badge/github.com/thegeeklab/wp-github-comment)](https://goreportcard.com/report/github.com/thegeeklab/wp-github-comment)
[![GitHub contributors](https://img.shields.io/github/contributors/thegeeklab/wp-github-comment)](https://github.com/thegeeklab/wp-github-comment/graphs/contributors)
[![Source: GitHub](https://img.shields.io/badge/source-github-blue.svg?logo=github&logoColor=white)](https://github.com/thegeeklab/wp-github-comment)
[![License: MIT](https://img.shields.io/github/license/thegeeklab/wp-github-comment)](https://github.com/thegeeklab/wp-github-comment/blob/main/LICENSE)

Woodpecker CI plugin to add comments to GitHub Issues and Pull Requests. You can find the full documentation at [https://wp-plugin-index.geekdocs.de](https://wp-plugin-index.geekdocs.de/plugins/wp-github-comment).

## Contributors

Special thanks to all [contributors](https://github.com/thegeeklab/wp-github-comment/graphs/contributors). If you would like to contribute, please see the [instructions](https://github.com/thegeeklab/wp-github-comment/blob/main/CONTRIBUTING.md).

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/thegeeklab/wp-github-comment/blob/main/LICENSE) file for details.

==> v1.0.5.zip: wp-github-comment/README.md <==
# wp-github-comment

Woodpecker CI plugin to add comments to GitHub Issues and Pull Requests

[![Build Status](https://ci.thegeeklab.de/api/badges/thegeeklab/wp-github-comment/status.svg)](https://ci.thegeeklab.de/repos/thegeeklab/wp-github-comment)
[![Docker Hub](https://img.shields.io/badge/dockerhub-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/thegeeklab/wp-github-comment)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/wp-github-comment)
[![Go Report Card](https://goreportcard.com/badge/github.com/thegeeklab/wp-github-comment)](https://goreportcard.com/report/github.com/thegeeklab/wp-github-comment)
[![GitHub contributors](https://img.shields.io/github/contributors/thegeeklab/wp-github-comment)](https://github.com/thegeeklab/wp-github-comment/graphs/contributors)
[![Source: GitHub](https://img.shields.io/badge/source-github-blue.svg?logo=github&logoColor=white)](https://github.com/thegeeklab/wp-github-comment)
[![License: MIT](https://img.shields.io/github/license/thegeeklab/wp-github-comment)](https://github.com/thegeeklab/wp-github-comment/blob/main/LICENSE)

Woodpecker CI plugin to add comments to GitHub Issues and Pull Requests. You can find the full documentation at [https://woodpecker-plugins.geekdocs.de](https://woodpecker-plugins.geekdocs.de/plugins/wp-github-comment).

## Contributors

Special thanks to all [contributors](https://github.com/thegeeklab/wp-github-comment/graphs/contributors). If you would like to contribute, please see the [instructions](https://github.com/thegeeklab/wp-github-comment/blob/main/CONTRIBUTING.md).

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/thegeeklab/wp-github-comment/blob/main/LICENSE) file for details.
